@@ -57,7 +57,7 @@ public class Individual {
 
     public final Date birth;
 
-    public final Integer bStatus;
+    public final BigDecimal bStatus;
 
     public final Character sex;
 
@@ -69,15 +69,22 @@ public class Individual {
 
     public final Integer dCause;
 
-    public final Integer dCauseConfidence;
+    public final Integer dCauseNatureConfidence;
+
+    public final Integer dCauseAgentConfidence;
+
+    public final Date entrydate;
+
+    public final Character entrytype;
 
     public final Date matured;
 
     public final Date ranked;
 
     public Individual(String sname, Integer bioId, String name, String pid,
-            Date birth, Integer bStatus, Character sex, BigDecimal matGrp,
-            Date statDate, Integer status, Integer dCause, Integer dCauseConfidence,
+            Date birth, BigDecimal bStatus, Character sex, BigDecimal matGrp,
+            Date statDate, Integer status, Integer dCause, Integer dCauseNatureConfidence,
+            Integer dCauseAgentConfidence, Date entrydate, Character entrytype,
             Date matured, Date ranked) {
         assert (sname != null && bioId != null && name != null && birth != null);
         this.sname = sname;
@@ -91,7 +98,10 @@ public class Individual {
         this.statDate = statDate;
         this.status = status;
         this.dCause = dCause;
-        this.dCauseConfidence = dCauseConfidence;
+        this.dCauseNatureConfidence = dCauseNatureConfidence;
+        this.dCauseAgentConfidence = dCauseAgentConfidence;
+        this.entrydate = entrydate;
+        this.entrytype = entrytype;
         this.matured = matured;
         this.ranked = ranked;
     }
@@ -108,7 +118,10 @@ public class Individual {
         this.statDate = individual.statDate;
         this.status = individual.status;
         this.dCause = individual.dCause;
-        this.dCauseConfidence = individual.dCauseConfidence;
+        this.dCauseNatureConfidence = individual.dCauseNatureConfidence;
+        this.dCauseAgentConfidence = individual.dCauseAgentConfidence;
+        this.entrydate = individual.entrydate;
+        this.entrytype = individual.entrytype;
         this.matured = individual.matured;
         this.ranked = individual.ranked;
     }
@@ -159,8 +172,14 @@ public class Individual {
             e.setAttribute("status", status.toString());
         if (dCause != null)
             e.setAttribute("dCause", dCause.toString());
-        if (dCauseConfidence != null)
-            e.setAttribute("dCauseConfidence", dCauseConfidence.toString());
+        if (dCauseNatureConfidence != null)
+            e.setAttribute("dCauseNatureConfidence", dCauseNatureConfidence.toString());
+        if (dCauseAgentConfidence != null)
+            e.setAttribute("dCauseAgentConfidence", dCauseAgentConfidence.toString());
+        if (entrydate != null)
+            e.setAttribute("entrydate", Babase.dateToXMLString(entrydate));
+        if (entrytype != null)
+            e.setAttribute("entrytype", entrytype.toString());
         if (matured != null)
             e.setAttribute("matured", Babase.dateToXMLString(matured));
         if (ranked != null)
@@ -174,7 +193,7 @@ public class Individual {
                 .getAttribute("bioId")), e.getAttribute("name"), e
                 .hasAttribute("pid") ? e.getAttribute("pid") : null, Babase
                 .xmlStringToDate(e.getAttribute("birth")), e
-                .hasAttribute("bStatus") ? new Integer(e
+                .hasAttribute("bStatus") ? new BigDecimal(e
                 .getAttribute("bStatus")) : null,
                 e.hasAttribute("sex") ? new Character(e.getAttribute("sex")
                         .charAt(0)) : null,
@@ -186,8 +205,14 @@ public class Individual {
                         .getAttribute("status")) : null, e
                         .hasAttribute("dCause") ? new Integer(e
                         .getAttribute("dCause")) : null, e
-                        .hasAttribute("dCauseConfidence") ? new Integer(e
-                        .getAttribute("dCauseConfidence")) : null, e
+                        .hasAttribute("dCauseNatureConfidence") ? new Integer(e
+                        .getAttribute("dCauseNatureConfidence")) : null, e
+                        .hasAttribute("dCauseAgentConfidence") ? new Integer(e
+                        .getAttribute("dCauseAgentConfidence")) : null, e
+                        .hasAttribute("entrydate") ? Babase.xmlStringToDate(e
+                        .getAttribute("entrydate")) : null, e
+                        .hasAttribute("entrytype") ? new Character(e
+                        .getAttribute("entrytype").charAt(0)) : null, e
                         .hasAttribute("matured") ? Babase.xmlStringToDate(e
                         .getAttribute("matured")) : null, e
                         .hasAttribute("ranked") ? Babase.xmlStringToDate(e
