@@ -32,8 +32,14 @@ public class IndividualHeader extends Individual implements Header {
             buf.append("<br>status: " + status);
         if (dCause != null)
             buf.append("<br>dCause: " + dCause);
-        if (dCauseConfidence != null)
-            buf.append("<br>dCauseConfidence: " + dCauseConfidence);
+        if (dCauseNatureConfidence != null)
+            buf.append("<br>dCauseNatureConfidence: " + dCauseNatureConfidence);
+        if (dCauseAgentConfidence != null)
+            buf.append("<br>dCauseAgentConfidence: " + dCauseAgentConfidence);
+        if (entrydate != null)
+            buf.append("<br>Entrydate: " + Babase.dateToString(entrydate));
+        if (entrytype != null)
+            buf.append("<br>Entrytype: " + entrytype);
         if (matured != null)
             buf.append("<br>matured: " + Babase.dateToString(matured));
         if (ranked != null)
